@@ -1,13 +1,9 @@
 from testcase.app.disable_module import DisableModule
 from testcase.app.surface_mse_module import SurfaceMSE
-from worker import App
+from worker.app import App
 
 
 class DrillingEfficiency(App):
-
     # override
     def get_modules(self):
-        return [
-            SurfaceMSE,
-            DisableModule
-        ]
+        return [SurfaceMSE, DisableModule]
