@@ -1,6 +1,6 @@
 import time
 
-from worker import Module
+from worker.app.modules import Module
 
 
 class TestRedis(Module):
@@ -8,7 +8,7 @@ class TestRedis(Module):
     collection = "None"
 
     module_state_fields = {
-        'message': str,
+        "message": str,
     }
 
     # override
@@ -59,10 +59,7 @@ class TestRedis(Module):
             time.sleep(0.1)  # back-off to prevent blocking by redis
 
         # Delete Multiple
-        state_keys = [
-            self.get_formatted_state_key(asset_id, module.app_key, module.module_key)
-            for module in modules
-        ]
+        state_keys = [self.get_formatted_state_key(asset_id, module.app_key, module.module_key) for module in modules]
 
         multiple_state_keys = state_keys[0:4]
         print(f"Deleting following {multiple_state_keys=}")
