@@ -1,31 +1,31 @@
-from typing import List, Union
+from typing import List, Optional
 
+from worker import constants, exceptions
 from worker.app.modules import Module
 from worker.app.modules.time_activity_module import TimeActivityModule
+from worker.data.enums import EventType, RerunMode
 from worker.data.operations import gather_data_for_period
-from worker.event import Event, EventType
+from worker.event import Event
 from worker.event.scheduled import ScheduledEvent
 from worker.event.stream import StreamEvent
-from worker.framework import constants
 from worker.mixins.logging import LoggingMixin
 from worker.mixins.rollbar import RollbarMixin
+from worker.partial_rerun_merge.models import RerunMergeCacheUpdater
 from worker.state.mixins import RedisMixin
 from worker.state.state import State
-from worker import exceptions
 
 
 class App(RedisMixin, LoggingMixin, RollbarMixin):
     """
     The apps is designed to receive the events of a single asset
     """
-    app_state_fields = {
-        'asset_id': int,
-        'last_processed_timestamp': int
-    }
+
+    app_key = constants.get("global.app-key")
+    app_name = constants.get("global.app-name")
+
+    app_state_fields = {"asset_id": int, "last_processed_timestamp": int}
 
     def __init__(self, *args, **kwargs):
-        self.app_key = constants.get('global.app-key')
-        self.app_name = constants.get('global.app-name')
         self.module_key = None
 
         self.event_type: EventType = None
@@ -38,20 +38,22 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
     def load(self, event_type: EventType, event: Event):
         """
         :param event_type:
-        :param event: a scheduler event or wits stream
+        :param event: a scheduler event or wits stream; belong to one asset
         :return:
         """
         self.event_type = event_type
 
-        max_lookback_seconds = self.get_max_lookback_seconds()
         self.asset_id = event.asset_id
 
         self.state = self.load_state()
 
+        max_lookback_seconds = self.get_max_lookback_seconds()
         event = self.load_event(event, max_lookback_seconds)
 
         valid_stream_collections = self.get_valid_stream_collections()
-        self.event = self.filter_event_for_collections(self.event_type, valid_stream_collections, event)  # event records
+        self.event = self.filter_event_for_collections(
+            self.event_type, valid_stream_collections, event
+        )  # event records
 
         self.log_event(self.event, max_lookback_seconds)  # event records
 
@@ -67,12 +69,15 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
 
         self.log(
             self.asset_id,
-            text=f"Received {batch_size} elements from {start_time} to {end_time}. {max_lookback_seconds} seconds of initial data are lookback."
+            text=(
+                f"Received {batch_size} elements from {start_time} to {end_time}. "
+                f"{max_lookback_seconds} seconds of initial data are lookback."
+            ),
         )
 
     @staticmethod
     def get_valid_stream_collections():
-        valid_collections = constants.get('global.valid-stream-collections', [])
+        valid_collections = constants.get("global.valid-stream-collections", [])
         if not isinstance(valid_collections, (str, list)):
             raise TypeError("Incorrect type of valid-stream-collections in global constants")
 
@@ -91,7 +96,9 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         time_modules = [module for module in self.get_modules() if issubclass(module, TimeActivityModule)]
         maximum_lookback = 0
         for module in time_modules:
-            module_lookback = constants.get('{}.{}.lookback-duration'.format(self.app_key, module.module_key), default=0)
+            module_lookback = constants.get(
+                "{}.{}.lookback-duration".format(self.app_key, module.module_key), default=0
+            )
             maximum_lookback = max(module_lookback, maximum_lookback)
 
         return maximum_lookback
@@ -100,7 +107,7 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         if self.event_type == EventType.SCHEDULER:
             return self.load_scheduler_event(self.asset_id, event, max_lookback_seconds)
 
-        if self.event_type == EventType.WITS_STREAM:
+        if self.event_type == EventType.STREAM:
             return self.load_wits_stream_event(self.asset_id, event, max_lookback_seconds)
 
         return None
@@ -125,7 +132,7 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         return event
 
     def filter_event_for_duplicates(self, event) -> list:
-        last_processed_timestamp = self.state.get('last_processed_timestamp') or 0
+        last_processed_timestamp = self.state.get("last_processed_timestamp") or 0
 
         # If event is a single record and greater than the last processed timestamp, return the event
         if len(event) == 1 and event[0].get("timestamp") > last_processed_timestamp:
@@ -155,7 +162,7 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         :return: list of WITS data between the last processed timestamp and the final event item timestamp
         """
 
-        start_timestamp = self.state.get('last_processed_timestamp', event[0].start_time - 1)
+        start_timestamp = self.state.get("last_processed_timestamp", event[0].start_time - 1)
         end_timestamp = event[-1].start_time
 
         # the event is converted from scheduler to wits stream
@@ -163,8 +170,8 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
             asset_id=asset_id,
             start=start_timestamp - max_lookback_seconds,
             end=end_timestamp,
-            limit=constants.get('global.query-limit'),
-            fields=constants.get('global.wits_query_fields', None)
+            limit=constants.get("global.query-limit"),
+            fields=constants.get("global.wits_query_fields", None),
         )
 
         return scheduler_event
@@ -185,9 +192,9 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         # If all record timestamps are before the last processed timestamp,
         # the first timestamp will be the last processed timestamp from cache
         if not records:
-            first_timestamp = self.state.get('last_processed_timestamp') or 0
+            first_timestamp = self.state.get("last_processed_timestamp") or 0
         else:
-            first_timestamp = records[0].get('timestamp')
+            first_timestamp = records[0].get("timestamp")
 
         if not first_timestamp:
             return records
@@ -200,8 +207,8 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
                 asset_id=asset_id,
                 start=first_timestamp - max_lookback_seconds,
                 end=end_timestamp,
-                limit=constants.get('global.query-limit'),
-                fields=constants.get('global.wits_query_fields', None)
+                limit=constants.get("global.query-limit"),
+                fields=constants.get("global.wits_query_fields", None),
             )
 
             records = previous_events + records
@@ -213,15 +220,15 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         try:
             return int(event[0]["asset_id"])
         except Exception:
-            raise Exception('Event does not contain asset_id: {}'.format(event))
+            raise Exception(f"Event does not contain asset_id: {event}")
 
-    def load_state(self, state_key: Union[str, None] = None, raise_warnings: bool = False) -> dict:
+    def load_state(self, state_key: Optional[str] = None, raise_warnings: bool = False) -> dict:
         previous_state = super().load_state(state_key=state_key, raise_warnings=raise_warnings)
 
         state = State(self.app_state_fields, previous_state)
 
-        if not state.get('asset_id', None):
-            state['asset_id'] = self.asset_id
+        if not state.get("asset_id", None):
+            state["asset_id"] = self.asset_id
 
         return state
 
@@ -239,7 +246,9 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
             try:
                 module = module_type(self.state, rollbar=self.rollbar)
             except Exception:
-                raise exceptions.Misconfigured("Module {0} not able to initialize for asset_id {1}".format(module_type, self.asset_id))
+                raise exceptions.Misconfigured(
+                    "Module {0} not able to initialize for asset_id {1}".format(module_type, self.asset_id)
+                )
 
             try:
                 module.run(self.event)  # event records
@@ -248,5 +257,34 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
                 ex.args += (message,)  # Adding message to existing Exception
                 raise
 
-        last_processed_timestamp = self.event[-1].get('timestamp')  # event records
-        self.state['last_processed_timestamp'] = last_processed_timestamp
+        last_processed_timestamp = self.event[-1].get("timestamp")  # event records
+        self.state["last_processed_timestamp"] = last_processed_timestamp
+
+    @classmethod
+    def update_cache(cls, merger: "PartialRerunMerge") -> None:
+        """
+        This function updates the cache of the original asset with the rerun asset's cache
+
+        If in any app that is extending this class, it needs to be overridden, it can be done so.
+
+        :param merger: PartialRerunMerge object
+        :return: None
+        """
+        if merger.rerun_mode == RerunMode.HISTORICAL:
+            return
+
+        original_asset_id = merger.original_asset_id
+        rerun_asset_id = merger.rerun_asset_id
+
+        redis_handler = RedisMixin()
+
+        original_state_key = redis_handler.get_formatted_state_key(original_asset_id, cls.app_key)
+        rerun_state_key = redis_handler.get_formatted_state_key(rerun_asset_id, cls.app_key)
+
+        original_state = redis_handler.load_state(original_state_key)
+        rerun_state = redis_handler.load_state(rerun_state_key)
+
+        original_state = RerunMergeCacheUpdater.default_updater(original_state, rerun_state)
+
+        redis_handler.state = original_state
+        redis_handler.save_state(original_state_key)
