@@ -1,9 +1,10 @@
+from typing import Dict, Union
+
 import numpy as np
-from typing import Union, Dict
 
-from worker.data.activity import Activity
-from worker.data.enums import DataStatus, ChannelStatus
 from worker.data import operations
+from worker.data.activity import Activity
+from worker.data.enums import ChannelStatus, DataStatus
 
 
 class Channel(float):
@@ -46,6 +47,7 @@ class WITS:
     - Access any data status of a wits data attribute by wits.hole_depth.status
     - Data status is only available for non None wits attributes
     """
+
     data = {
         "entry_at": int,
         "hole_depth": Channel,
@@ -71,11 +73,9 @@ class WITS:
         "lag_depth": Channel,
         "state": Activity,
         "boost_pump_flow_in": Channel,
-        "annular_back_pressure": Channel
-    }
-    metadata = {
-        "drillstring": str
+        "annular_back_pressure": Channel,
     }
+    metadata = {"drillstring": str}
     spm_channels = ["pump_spm_1", "pump_spm_2", "pump_spm_3", "pump_spm_4"]
     status = {}
 
@@ -179,11 +179,13 @@ class WITS:
 
         self.wits_json.pop("data_raw", None)
         self.wits_json["data"] = {key: getattr(self, key) for key in self.data}
-        self.wits_json["data"].update({
-            f"{key}_data_status": getattr(self, key).status.value
-            for key in self.data
-            if self.data.get(key) == Channel and getattr(self, key) is not None
-        })
+        self.wits_json["data"].update(
+            {
+                f"{key}_data_status": getattr(self, key).status.value
+                for key in self.data
+                if self.data.get(key) == Channel and getattr(self, key) is not None
+            }
+        )
         # convert state from Activity type to str
         self.wits_json["data"]["state"] = self.wits_json["data"]["state"].value
         self.wits_json["status"] = {key: getattr(self, key) for key in self.status}
@@ -243,15 +245,19 @@ class WITS:
         :param required_wits_channels: List of required channels
         :return: Boolean value. True if all the required channels are available, else False
         """
-        return all(operations.is_in_and_not_none(self.get_wits_data(required_wits_channels), channel)
-                   for channel in required_wits_channels)
+        return all(
+            operations.is_in_and_not_none(self.get_wits_data(required_wits_channels), channel)
+            for channel in required_wits_channels
+        )
 
     def set_pump_spm_total(self):
         """This function sets the pump_spm_total attribute value based on individual spm values"""
 
-        pump_spm_total = sum(getattr(self, spm_channel)
-                             for spm_channel in self.spm_channels
-                             if (getattr(self, spm_channel) and getattr(self, spm_channel) >= 0))
+        pump_spm_total = sum(
+            getattr(self, spm_channel)
+            for spm_channel in self.spm_channels
+            if (getattr(self, spm_channel) and getattr(self, spm_channel) >= 0)
+        )
 
         setattr(self, "pump_spm_total", pump_spm_total)
 
@@ -282,12 +288,12 @@ class WITS:
             if orig_value is None:
                 continue
 
-            valid_range = properties.get('range')
-            operation = properties.get('operation', None)
+            valid_range = properties.get("range")
+            operation = properties.get("operation", None)
 
             new_value = None
 
-            if operation == 'clip':
+            if operation == "clip":
                 new_value = np.clip(orig_value, *valid_range)
             elif operation is None:
                 if valid_range[0] <= orig_value <= valid_range[-1]:
