@@ -1,24 +1,25 @@
 import itertools
-import json
 from typing import Dict, Union
-from worker.data.api import API
 
-from worker import App
-from worker.event import Event, EventType
-from worker.event.scheduled import SingleScheduledEvent, ScheduledEvent
+from worker.app import App
+from worker.data.api import API
+from worker.data.enums import EventType
+from worker.data.operations import get_cleaned_event_and_type
+from worker.event import Event
+from worker.event.scheduled import ScheduledEvent, SingleScheduledEvent
 from worker.event.stream import StreamEvent
 from worker.exceptions import EventFormatError
-from worker.framework import constants
-
+from worker.partial_rerun_merge.merge import PartialRerunMerge
 
 api = API()
 
 
 class EventHandler:
-    def __init__(self, app: App):
+    def __init__(self, app: App, merger: PartialRerunMerge):
         self.app: App = app
         self.event_type: EventType = None
         self.event_by_asset_id: Dict[int, Event] = None
+        self.merger: PartialRerunMerge = merger
 
     def process(self, event: Union[str, dict]):
         """
@@ -38,42 +39,37 @@ class EventHandler:
         Args:
             event (Union[str, dict]): lambda handler event
         """
-        self.event_type = self.get_event_type()
-        event = self.clean_event(event)
+        event, event_type = get_cleaned_event_and_type(event)
+        self.event_type = event_type
         self.event_by_asset_id = self.format_event(self.event_type, event)
 
     def _run(self):
-        """ Full run of the events based on their asset id """
-        for asset_id, event in self.event_by_asset_id.items():
+        """Full run of the events based on their asset id"""
+        for _asset_id, event in self.event_by_asset_id.items():
+            if self.event_type == EventType.PARTIAL_RERUN:
+                self.merger.perform_merge(event)
+                continue
+
             self.app.load(self.event_type, event)
             self.app.run_modules()
             self.app.save_state()
             event.complete_event(api)
 
     @staticmethod
-    def get_event_type() -> EventType:
-        event_type: str = constants.get('global.event-type', "")
-        return EventType(event_type)
-
-    @staticmethod
-    def clean_event(event):
-        if not event:
-            raise Exception("Empty event")
-
-        if isinstance(event, (str, bytes, bytearray)):
-            event = json.loads(event)
-
-        return event
-
-    @staticmethod
-    def format_event(event_type: EventType, event: list) -> dict:
+    def format_event(event_type: EventType, event: Union[list, dict]) -> dict:
         """
         validate the wits_stream event, flatten and organize the data into a desired format
         :param event_type: type of event
         :param event: the wits or scheduler json event
         :return: a dict of records that are grouped by the asset_ids
         """
-        if event_type == EventType.SCHEDULER:
+        if event_type == EventType.PARTIAL_RERUN:
+            if not isinstance(event, dict):
+                raise EventFormatError("Invalid event!")
+
+            return {event["data"]["asset_id"]: event.copy()}
+
+        elif event_type == EventType.SCHEDULER:
             if not isinstance(event[0], list):
                 raise EventFormatError("Invalid event!")
 
@@ -89,9 +85,6 @@ class EventHandler:
         events.sort(key=lambda single_event: single_event.asset_id)
         groups = itertools.groupby(events, key=lambda single_event: single_event.asset_id)
 
-        events_by_asset_id = {
-            group: merging_function(list(dataset))
-            for group, dataset in groups
-        }
+        events_by_asset_id = {group: merging_function(list(dataset)) for group, dataset in groups}
 
         return events_by_asset_id
