@@ -5,37 +5,33 @@ from enum import Enum
 import numpy as np
 
 from worker.data.alert import Alerter
+from worker.data.operations import equal, is_stream_app, nanround
 from worker.data.serialization import serialization
 from worker.data.unit_conversions import US_LIQUID_GAL_to_INCH3
 from worker.mixins.logging import Logger
 from worker.wellbore.model.element import Element
-from worker.wellbore.model.enums import PipeType, PipeMaterial, HoleType
-from worker.data.operations import nanround, equal, is_stream_app
+from worker.wellbore.model.enums import HoleType, PipeMaterial, PipeType
 
 
 @serialization
 class Pipe(Element):
     SERIALIZED_VARIABLES = {
-        'top_depth': float,
-        'bottom_depth': float,
-        'length': float,
-
-        'inner_diameter': float,
-        'outer_diameter': float,
-
-        'joint_length': float,
-        'max_outer_diameter': float,
-        'inner_diameter_tooljoint': float,
-        'outer_diameter_tooljoint': float,
-        'tool_joint_length_per_joint': float,
-        'linear_mass_in_air': float,
-        'order': float,
-
-        'pipe_material': PipeMaterial,
-        'grade': float,
-
-        'tool_joint_length_ratio': float,
-        'pipe_type': PipeType,
+        "top_depth": float,
+        "bottom_depth": float,
+        "length": float,
+        "inner_diameter": float,
+        "outer_diameter": float,
+        "joint_length": float,
+        "max_outer_diameter": float,
+        "inner_diameter_tooljoint": float,
+        "outer_diameter_tooljoint": float,
+        "tool_joint_length_per_joint": float,
+        "linear_mass_in_air": float,
+        "order": float,
+        "pipe_material": PipeMaterial,
+        "grade": float,
+        "tool_joint_length_ratio": float,
+        "pipe_type": PipeType,
     }
 
     """
@@ -48,26 +44,27 @@ class Pipe(Element):
 
     This class is extended by the other drillpipe components.
     """
+
     def __init__(self, **kwargs):
         super(Pipe, self).__init__(**kwargs)
 
-        self.inner_diameter = kwargs['inner_diameter']
-        self.outer_diameter = kwargs['outer_diameter']
+        self.inner_diameter = kwargs["inner_diameter"]
+        self.outer_diameter = kwargs["outer_diameter"]
 
-        self.joint_length = kwargs.get('component_length', kwargs.get('joint_length'))
-        self.max_outer_diameter = kwargs.get('max_outer_diameter')
-        self.inner_diameter_tooljoint = kwargs.get('inner_diameter_tooljoint')
-        self.outer_diameter_tooljoint = kwargs.get('outer_diameter_tooljoint')
-        self.tool_joint_length_per_joint = kwargs.get('length_tooljoint') or kwargs.get('tool_joint_length_per_joint')
-        self.linear_mass_in_air = kwargs.get('linear_weight', kwargs.get('linear_mass_in_air'))
-        self.order = kwargs.get('order')
+        self.joint_length = kwargs.get("component_length", kwargs.get("joint_length"))
+        self.max_outer_diameter = kwargs.get("max_outer_diameter")
+        self.inner_diameter_tooljoint = kwargs.get("inner_diameter_tooljoint")
+        self.outer_diameter_tooljoint = kwargs.get("outer_diameter_tooljoint")
+        self.tool_joint_length_per_joint = kwargs.get("length_tooljoint") or kwargs.get("tool_joint_length_per_joint")
+        self.linear_mass_in_air = kwargs.get("linear_weight", kwargs.get("linear_mass_in_air"))
+        self.order = kwargs.get("order")
 
-        self.pipe_material = kwargs.get('material')
-        self.grade = kwargs.get('grade')
+        self.pipe_material = kwargs.get("material")
+        self.grade = kwargs.get("grade")
 
         self.set_tool_joint_length_ratio()
 
-        family = kwargs.get('family') or ""
+        family = kwargs.get("family") or ""
         self.pipe_type = PipeType.determine_type(family)
 
     def get_max_outer_diameter(self):
@@ -98,14 +95,14 @@ class Pipe(Element):
         Compute the total inner area of the pipe body
         :return: inner area of the pipe body in INCH^2
         """
-        return np.pi / 4 * (self.inner_diameter ** 2)
+        return np.pi / 4 * (self.inner_diameter**2)
 
     def get_pipe_od_area(self):
         """
         Compute the total outer area of the pipe body
         :return: outer area of the pipe body in INCH^2
         """
-        return np.pi / 4 * (self.outer_diameter ** 2)
+        return np.pi / 4 * (self.outer_diameter**2)
 
     def get_pipe_tool_joint(self):
         """
@@ -126,11 +123,8 @@ class Pipe(Element):
         if not self.is_valid_tool_joint():
             return area_body
 
-        area_tj = np.pi / 4 * (self.inner_diameter_tooljoint ** 2)  # in INCH^2
-        return (
-            area_body * (1 - self.tool_joint_length_ratio)
-            + area_tj * self.tool_joint_length_ratio
-        )
+        area_tj = np.pi / 4 * (self.inner_diameter_tooljoint**2)  # in INCH^2
+        return area_body * (1 - self.tool_joint_length_ratio) + area_tj * self.tool_joint_length_ratio
 
     def compute_outer_area_tool_joint_adjusted(self):
         """
@@ -141,7 +135,7 @@ class Pipe(Element):
         if not self.is_valid_tool_joint():
             return area_body
 
-        area_tj = np.pi / 4 * (self.outer_diameter_tooljoint ** 2)  # in INCH^2
+        area_tj = np.pi / 4 * (self.outer_diameter_tooljoint**2)  # in INCH^2
         r = self.tool_joint_length_ratio
         return area_body * (1 - r) + area_tj * r
 
@@ -228,20 +222,17 @@ class Pipe(Element):
 
     def eq_without_length(self, other):
         params = [
-            'pipe_type',
-            'inner_diameter',
-            'outer_diameter',
-            'inner_diameter_tooljoint',
-            'outer_diameter_tooljoint',
-            'linear_mass_in_air'
+            "pipe_type",
+            "inner_diameter",
+            "outer_diameter",
+            "inner_diameter_tooljoint",
+            "outer_diameter_tooljoint",
+            "linear_mass_in_air",
         ]
         return equal(self, other, params)
 
     def eq_id_and_od(self, other):
-        params = [
-            'inner_diameter',
-            'outer_diameter'
-        ]
+        params = ["inner_diameter", "outer_diameter"]
         return equal(self, other, params)
 
     def __repr__(self):
@@ -280,21 +271,20 @@ class Agitator(Pipe):
 @serialization
 class Bit(Element):
     SERIALIZED_VARIABLES = {
-        'top_depth': float,
-        'bottom_depth': float,
-        'length': float,
-
-        'size': float,
-        'tfa': float,
-        'pipe_type': PipeType
+        "top_depth": float,
+        "bottom_depth": float,
+        "length": float,
+        "size": float,
+        "tfa": float,
+        "pipe_type": PipeType,
     }
 
     # TODO extra items to be implemented later
     def __init__(self, **kwargs):
         super(Bit, self).__init__(**kwargs)
 
-        self.size = float(kwargs['size'])
-        self.tfa = float(kwargs['tfa'])
+        self.size = float(kwargs["size"])
+        self.tfa = float(kwargs["tfa"])
         self.pipe_type = PipeType.BIT
 
     # override
@@ -317,16 +307,17 @@ class Bit(Element):
 @serialization
 class UnderReamer(Pipe):
     SERIALIZED_VARIABLES = deepcopy(Pipe.SERIALIZED_VARIABLES)
-    SERIALIZED_VARIABLES.update({
-        'activation_logic': str,
-        'ur_opened_od': float,
-        'ur_opened_depth': float,
-
-        'flow_rate': float,
-        '_is_opened': bool,
-        'tfa': float,
-        'alerted_at_timestamp': float,
-    })
+    SERIALIZED_VARIABLES.update(
+        {
+            "activation_logic": str,
+            "ur_opened_od": float,
+            "ur_opened_depth": float,
+            "flow_rate": float,
+            "_is_opened": bool,
+            "tfa": float,
+            "alerted_at_timestamp": float,
+        }
+    )
 
     class UnderReamerActivationType(Enum):
         ALREADY_ACTIVATED = "already_activated"
@@ -347,11 +338,11 @@ class UnderReamer(Pipe):
         self.alerted_at_timestamp: float = 0.0
         self.ALERT_BACKOFF_TIME = 3600
 
-        self.tfa = float(kwargs['tfa'])
-        self.ur_opened_depth = kwargs.get('ur_opened_depth')
-        self.ur_opened_od = float(kwargs['ur_opened_od'])
-        self.flow_rate = float(kwargs.get('flow_rate'))
-        self.activation_logic = self.ActivationLogic(kwargs['activation_logic'])
+        self.tfa = float(kwargs["tfa"])
+        self.ur_opened_depth = kwargs.get("ur_opened_depth")
+        self.ur_opened_od = float(kwargs["ur_opened_od"])
+        self.flow_rate = float(kwargs.get("flow_rate"))
+        self.activation_logic = self.ActivationLogic(kwargs["activation_logic"])
         self.pipe_type = PipeType.UNDERREAMER
 
     @property
@@ -423,8 +414,10 @@ class UnderReamer(Pipe):
 
     def trigger_alert(self, ur_opened_depth, start_reaming_depth):
         identifier = "ur_opened_in_cased_hole"
-        message = f"Attempted to open under-reamer inside cased hole at {ur_opened_depth}. " \
-                  f"Last casing shoe depth of {start_reaming_depth}. "
+        message = (
+            f"Attempted to open under-reamer inside cased hole at {ur_opened_depth}. "
+            f"Last casing shoe depth of {start_reaming_depth}. "
+        )
 
         current_timestamp = time.time()
 
@@ -433,8 +426,10 @@ class UnderReamer(Pipe):
             self.alerted_at_timestamp = current_timestamp
             Logger.warn(f"Alert created. identifier: {identifier}, message: {message}")
         else:
-            Logger.info(f"Alert created. identifier: {identifier}, message: {message}"
-                        f"However, not triggering alert because it was not triggered from Stream app")
+            Logger.info(
+                f"Alert created. identifier: {identifier}, message: {message}"
+                f"However, not triggering alert because it was not triggered from Stream app"
+            )
 
     def __repr__(self):
         return (
